#!/bin/bash

# Usage: ./do_test.sh <program> <prefix>
# Ex:    ./do_test.sh ./test_lzw/LZW_TL240204.j test_lzw

# Get the input file, test file, and sample output file from the argument
program="$1"   #ex. ./test_lzw/LZW_TL240204.j
prefix="$2"    #ex. test_lzw

# Define the temporary file name
temp_program="temp_program.j"

# Loop over each ${prefix}/test*.j file
for janus_main in ${prefix}/test*.j; do
    # Generate the expected output file name (e.g., LZW_test01.j -> LZW_test01.output)
    output_file="${janus_main%.j}.output"

    # Remove 'procedure main()' and the following lines, then create a temporary file
    sed '/procedure main()/,$d' "$program" > "$temp_program"

    # Append the content of the current janus file to the temporary file
    cat "$janus_main" >> "$temp_program"

    # Define the final output file for temporary results
    final_output="${janus_main%.j}_result.txt"

    # Process the temporary file with the jana command and output the result to the final output file
    jana "$temp_program" > "$final_output"

    # Compare the result with the expected output
    if cmp -s "$final_output" "$output_file"; then
        echo "${janus_main}: Outputs match."
    else
        echo "${janus_main}: Outputs do not match."
        cat $final_output
        #echo "---"
        #cat $output_file
        cat $final_output &> $output_file  # Generate output
    fi

    rm "$final_output"
done

# Remove the temporary file after processing
rm "$temp_program"
